//Bibliothek zum steuern der NeoPixel am Mikrocontroller
#include <Adafruit_NeoPixel.h>

//Bibliothek zum entprellen der Taster
#include <Bounce2.h>

//Taster 1 am GPIO13 angeschlossen
#define button1 13
//RGB Stripe 2 am GPIO16 angeschlossen
#define rgbStripe1 16

//Taster 2 am GPIO27 angeschlossen
#define button2 27
//RGB Stripe 2 am GPIO17 angeschlossen
#define rgbStripe2 17

//Bounce2 Objekte initialisieren für die Taster
Bounce btn1 = Bounce();
Bounce btn2 = Bounce();

//Anzahl der NeoPixel pro Modul / Stripe
const int NUM_PIXEL = 8;

//Initialisieren der Adafruit_NeoPixel Objekte
//für jeden Stripe wird ein Objekt benötigt.
Adafruit_NeoPixel pixelStripe1 = Adafruit_NeoPixel(NUM_PIXEL, rgbStripe1, NEO_GRB + NEO_KHZ800);
Adafruit_NeoPixel pixelStripe2 = Adafruit_NeoPixel(NUM_PIXEL, rgbStripe2, NEO_GRB + NEO_KHZ800);

//Farben für aktiviert / deaktiviert definieren
const uint32_t COLOR_ACTIVE = pixelStripe1.Color(255, 255, 255);
const uint32_t COLOR_DEACTIVE = pixelStripe1.Color(0, 0, 0);

//Felder zum speichern der Zustände der RGB Stripe
bool stripe1Active = false;
bool stripe2Active = false;

void setup() {
  //Einrichten des ersten Tasters
  btn1.attach(button1, INPUT_PULLUP);
  btn1.interval(25);

  //Einrichten des zweiten Tasters
  btn2.attach(button2, INPUT_PULLUP);
  btn2.interval(25);

  //Beginn der kommunikation mit den RGB Stripes
  pixelStripe1.begin();
  pixelStripe2.begin();
}

/**
* Befüllen eines RGB Stripes mit einer Farbe je nach Status
**/
void setPixelStripe(Adafruit_NeoPixel pixelStripe, bool isActive) {
  uint32_t color = COLOR_ACTIVE;
  if (!isActive) {
    color = COLOR_DEACTIVE;
  }
  pixelStripe.fill(color, 0, NUM_PIXEL);
  pixelStripe.show();
}

void loop() {
  //aktualisieren der Bounce2 Objekte
  btn1.update();
  btn2.update();

  //Wenn die Taste betätigt wird, dann...
  if (btn1.fell()) {
    //umkehren des zuvor gespeicherten Status
    stripe1Active = !stripe1Active;
    //aktualisieren des RGB Stripes
    setPixelStripe(pixelStripe1, stripe1Active);
  }

  if (btn2.fell()) {
    stripe2Active = !stripe2Active;
    setPixelStripe(pixelStripe2, stripe2Active);
  }
}